import { NextFunction, Request, Response } from 'express';
import {
  createRecipe, getAllRecipes, getRecipeById, getRecipesByUser
} from '../services/recipeService';

export async function postRecipe(
  req: Request, res: Response, next: NextFunction,
): Promise<void> {
  try {
    const recipe_id = await createRecipe(req.body);
    res.status(201).json({
      message: 'Recipe created',
      data: {
        recipe_id,
      },
    });
  } catch (error) {
    next(error);
  }
}

export async function indexRecipes(
  req: Request, res: Response, next: NextFunction,
): Promise<void> {
  try {
    const recipes = await getAllRecipes(req.query);
    res.status(200).json({ message: 'OK', data: recipes });
  } catch (error) {
    next(error);
  }
}

export async function searchRecipesByUser(
  req: Request, res: Response, next: NextFunction,
): Promise<void> {
  try {
    const recipes = await getRecipesByUser(req.query);
    recipes.length > 0 ? res.status(200).json({ message: 'OK', data: recipes }) : res.status(404).json();
  } catch (error) {
    next(error);
  }
}

export async function searchRecipeById(
  req: Request, res: Response, next: NextFunction,
) : Promise<void> {
  try {
    const recipe = await getRecipeById(req.params);
    if (recipe.length > 0) {
      res.status(200).json({ message: 'OK', data: recipe[0] });
    } else {
      res.status(404).json();
    }
  } catch (error) {
    next(error);
  }
}
