import { Knex } from 'knex';

interface InsertRecipeId{
  recipe_id: number
}

const recipe1 = {
  ingredients: 'Arroz e Carne',
  description: 'Arroz com Carne!',
  preparation_time: 10,
  difficulty: 10,
  user_id: '1',
  status: 'A',
  likes_number: 0,
  title: 'Arroz Carne',
  active: 1,
  portions: 5,
  tags: [
    { tag_id: 1 },
    { tag_id: 2 },
  ],
  steps: [
    {
      title: 'Passo 1',
      description: 'Lorem ipsum',
      position: 0,
    },
  ],
};

const recipe2 = {
  ingredients: 'Farinha; queijo; tomate',
  description: 'Pizza feita em casa sabor quatro queijos',
  preparation_time: 60,
  difficulty: 7,
  user_id: '123abc321cba',
  status: 'A',
  likes_number: 0,
  title: 'Pizza Quatro Queijos',
  active: 1,
  portions: 8,
  tags: [
    { tag_id: 1 },
  ],
  steps: [
    {
      title: 'Passo 1',
      description: 'Lorem ipsum',
      position: 0,
    },
    {
      title: 'Passo 2',
      description: 'Lorem ipsum',
      position: 1,
    },
  ],
};

const recipe3 = {
  ingredients: 'Arroz e Batata',
  description: 'Arroz com Batata!',
  preparation_time: 10,
  difficulty: 10,
  user_id: '1',
  status: 'A',
  likes_number: 0,
  title: 'Arroz Batata',
  active: 0,
  portions: 4,
  tags: [
    { tag_id: 1 },
  ],
  steps: [
    {
      title: 'Passo 1',
      description: 'Lorem ipsum',
      position: 0,
    },
    {
      title: 'Passo 2',
      description: 'Lorem ipsum',
      position: 1,
    },
  ],
};

/* eslint-disable import/prefer-default-export */
async function seed(knex: Knex) {
  // Deletes ALL existing entries
  await knex('recipes').del();

  // Inserts seed entries

  const [newRecipe1, newRecipe2, newRecipe3]: InsertRecipeId[] = await knex('recipes').insert([
    {
      ingredients: recipe1.ingredients,
      description: recipe1.description,
      preparation_time: recipe1.preparation_time,
      difficulty: recipe1.difficulty,
      user_id: recipe1.user_id,
      status: recipe1.status,
      likes_number: recipe1.likes_number,
      title: recipe1.title,
      portions: recipe1.portions,
    },
    {
      ingredients: recipe2.ingredients,
      description: recipe2.description,
      preparation_time: recipe2.preparation_time,
      difficulty: recipe2.difficulty,
      user_id: recipe2.user_id,
      status: recipe2.status,
      likes_number: recipe2.likes_number,
      title: recipe2.title,
      portions: recipe2.portions,
    },
    {
      ingredients: recipe3.ingredients,
      description: recipe3.description,
      preparation_time: recipe3.preparation_time,
      difficulty: recipe3.difficulty,
      user_id: recipe3.user_id,
      status: recipe3.status,
      likes_number: recipe3.likes_number,
      title: recipe3.title,
      active: recipe3.active,
      portions: recipe3.portions,
    },
  ], ['recipe_id']);

  await knex('recipes_tags').insert([
    {
      recipe_id: newRecipe1.recipe_id,
      tag_id: recipe1.tags[0].tag_id,
    },
    {
      recipe_id: newRecipe1.recipe_id,
      tag_id: recipe1.tags[1].tag_id,
    },
    {
      recipe_id: newRecipe2.recipe_id,
      tag_id: recipe2.tags[0].tag_id,
    },
    {
      recipe_id: newRecipe3.recipe_id,
      tag_id: recipe3.tags[0].tag_id,
    },
  ]);

  await knex('steps').insert([
    {
      recipe_id: newRecipe1.recipe_id,
      ...recipe1.steps[0],
    },
    {
      recipe_id: newRecipe2.recipe_id,
      ...recipe2.steps[0],
    },
    {
      recipe_id: newRecipe2.recipe_id,
      ...recipe2.steps[1],
    },
    {
      recipe_id: newRecipe3.recipe_id,
      ...recipe3.steps[0],
    },
    {
      recipe_id: newRecipe3.recipe_id,
      ...recipe3.steps[1],
    },
  ]);
}

module.exports = { seed };
