import {celebrate, Joi, Segments} from 'celebrate';
import express from 'express';
import healthCheck from './controllers/healthController';
import {indexRecipes, postRecipe, searchRecipeById, searchRecipesByUser} from './controllers/recipeController';
import indexTags from './controllers/tagController';

const routes = express.Router();

routes.get('/health', healthCheck);
routes.post('/recipes', celebrate({
  [Segments.BODY]: {
    title: Joi.string().required(),
    ingredients: Joi.array().required(),
    description: Joi.string().required(),
    preparation_time: Joi.number().required(),
    difficulty: Joi.number().required(),
    portions: Joi.number().required(),
    user_id: Joi.string().required(),
    status: Joi.string().required(),
    tags: Joi.array().required(),
    steps: Joi.array().required(),
  },
}), postRecipe);
routes.get('/recipes',
  celebrate({
    [Segments.QUERY]: {
      tag: Joi.alternatives().try(Joi.number(), Joi.array().items(Joi.number())),
      title: Joi.string(),
      recipeId: Joi.alternatives().try(Joi.number(), Joi.array().items(Joi.number())),
    },
  }), indexRecipes);
routes.get('/tags', indexTags);

routes.get('/recipes/user',
  celebrate({
    [Segments.QUERY]: {
      user: Joi.string(),
    },
  }), searchRecipesByUser);
routes.get('/recipes/:recipe_id', celebrate({
  [Segments.PARAMS]: {
    recipe_id: Joi.number(),
  },
}), searchRecipeById);

export default routes;
