import Recipe from '../models/recipe';
import {
  findAllRecipes,
  findRecipeById,
  findRecipesByListOfId,
  findRecipesByQueryParams,
  findRecipesByUser,
  saveRecipe
} from '../repositories/recipeRepository';

export async function createRecipe(recipe: Recipe): Promise<number> {
  const ingredients = Array.isArray(recipe.ingredients) ? recipe.ingredients.join(';') : recipe.ingredients;
  const toSave = { ...recipe, likes_number: 0, ingredients };
  return saveRecipe(toSave);
}

function mountRecipe(recipes: Recipe[]) {
  return recipes.map((recipe) => {
    const newIngredients = typeof recipe.ingredients === 'string' ? recipe.ingredients.split(';').map((ingredient) => ingredient.trim()) : recipe.ingredients;
    const newRecipe = recipe;
    newRecipe.ingredients = newIngredients;
    return newRecipe;
  });
}

export async function getAllRecipes(query: any): Promise<Recipe[]> {
  const { tag, title, recipeId } = query;
  let tags : number[] = [];
  let recipes: Recipe[];
  if (recipeId) {
    let ids : number[] = [];
    ids = ids.concat(recipeId);
    recipes = await findRecipesByListOfId(ids);
  } else if (tag || title) {
    tags = typeof tag !== 'undefined' ? tags.concat(tag) : [];
    recipes = await findRecipesByQueryParams(title, tags);
  } else {
    recipes = await findAllRecipes();
  }
  return mountRecipe(recipes);
}

export async function getRecipesByUser(query: any): Promise<Recipe[]> {
  const { user } = query;
  let recipes: Recipe[];
  recipes = await findRecipesByUser(user);
  return mountRecipe(recipes);
}

export async function getRecipeById(params: any): Promise<Recipe[]> {
  const { recipe_id } = params;
  const recipe = await findRecipeById(recipe_id);
  return mountRecipe(recipe);
}
